@@ -2,7 +2,7 @@ package Datahub::Factory::Pipeline::Transport;
 
 use Datahub::Factory::Sane;
 
-our $VERSION = '1.73';
+our $VERSION = '1.74';
 
 use Moo;
 use namespace::clean;
@@ -88,12 +88,22 @@ sub parse {
         'options' => $self->plugin_options('fixer', $fixer)
     };
 
-    my $conditional_fixers = $options->{'fixer'}->{$fixer}->{'options'}->{'fixers'};
-    foreach my $conditional_fixer (@{$conditional_fixers}) {
-        $options->{'fixer'}->{'conditionals'}->{$conditional_fixer} = {
-            'name' => $conditional_fixer,
-            'options' => $self->block_options(sprintf('plugin_fixer_%s', $conditional_fixer))
-        };
+    if (defined($options->{'fixer'}->{$fixer}->{'options'}->{'fixers'})) {
+        my $conditional_fixers;
+
+        if (ref($options->{'fixer'}->{$fixer}->{'options'}->{'fixers'}) ne 'ARRAY') {
+            my @items = ();
+            push @items, $options->{'fixer'}->{$fixer}->{'options'}->{'fixers'};
+            $options->{'fixer'}->{$fixer}->{'options'}->{'fixers'} = \@items;
+        }
+
+        $conditional_fixers = $options->{'fixer'}->{$fixer}->{'options'}->{'fixers'};
+        foreach my $conditional_fixer (@{$conditional_fixers}) {
+           $options->{'fixer'}->{'conditionals'}->{$conditional_fixer} = {
+               'name' => $conditional_fixer,
+               'options' => $self->block_options(sprintf('plugin_fixer_%s', $conditional_fixer))
+           };
+        }
     }
 
     return $options;
